#
# spec file for package jakarta-commons-discovery
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define short_name commons-discovery
%bcond_with tests
Name:           jakarta-%{short_name}
Version:        0.5
Release:        2.1
Summary:        Jakarta Commons Discovery
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://jakarta.apache.org/commons/discovery.html
Source0:        https://archive.apache.org/dist/commons/discovery/source/%{short_name}-%{version}-src.tar.gz
Source1:        https://repo1.maven.org/maven2/%{short_name}/%{short_name}/%{version}/%{short_name}-%{version}.pom
Source100:      commons-discovery-build.xml
BuildRequires:  ant
BuildRequires:  commons-logging >= 1.1.1
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  javapackages-local >= 6
Provides:       %{short_name} = %{version}
Obsoletes:      %{short_name} < %{version}
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
%endif

%description
The Discovery component is about discovering, or finding,
implementations for pluggable interfaces.  Pluggable interfaces are
specified with the intent that multiple implementations are, or will
be, available to provide the service described by the interface.
Discovery provides facilities for finding and instantiating classes and
for lifecycle management of singleton (factory) classes.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains the javadoc documentation for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
cp %{SOURCE100} build.xml
mkdir -p lib

%build
build-jar-repository -s lib commons-logging
ant \
%if %{without tests}
    -Dtest.skip=true \
%endif
    package javadoc

%install
# jar
install -d -m 0755 %{buildroot}%{_javadir}
install -m 644 target/%{short_name}-*.jar %{buildroot}%{_javadir}/%{short_name}.jar
(cd %{buildroot}%{_javadir} && ln -s %{short_name}.jar %{name}.jar)

install -d -m 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/%{short_name}.pom
%add_maven_depmap %{short_name}.pom %{short_name}.jar

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt
%{_javadir}/%{name}.jar

%files javadoc
%doc %{_javadocdir}/%{name}

%changelog
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Spec file cleanup
* Wed May  3 2023 Pedro Monreal <pmonreal@suse.com>
- Update to 0.5:
  * Breaking changes: The minimum JDK requirement is now JDK 1.5.
    The provided binaries will not work on lower JDKs. The source
    has been updated to leverage Generics and other JDK 1.5 features
    where possible, and requires JDK 1.5 to compile.
  * Dependencies: Commons Discovery depends on Commons Logging.
    It is built against version 1.1.1.
  * New features: Discovery APIs use Java5 Generics.
  * Known bugs/limitations: resource.classes.DiscoverClasses doesn't
    work with Oracle embedded JVM in DBMS, see DISCOVERY-13:
  - https://issues.apache.org/jira/browse/DISCOVERY-13
  * Deprecations:
  - Classes in org.apache.commons.discovery.log package
    have been deprecated, depending on Apache Commons Logging 1.1.1
    there is no more circular dependency between Apache Commons
    Discovery and Apache Commons Logging.
  - setLog(org.apache.commons.logging.Log) methods have been
    deprecated too, they are not thread-safe.
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Tue Mar  1 2022 Fridrich Strba <fstrba@suse.com>
- Distribute commons-discovery as maven artifact
* Mon Sep 13 2021 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Added build support for Enterprise Linux.
* Fri Sep  8 2017 fstrba@suse.com
- Specify java target and source version to 1.6 in order to allow
  building with jdk9
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner a bit
- Do not disable bytecode check but rather set the versions to ant
* Thu May 15 2014 darin@darins.net
- disable bytecode check on sle_11
- removed %%mkrel from Version
* Fri Sep 13 2013 mvyskocil@suse.com
- provide osgi(org.apache.commons.discovery) to satisfy axis
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Oct 16 2012 mvyskocil@suse.com
- tiny cleanup of a specfile
* Fri May 25 2012 mvyskocil@suse.cz
- fix a build with jdk7
- reformat spec a bit, remove obsoleted gcj parts and don't version javadoc dir
- build with commons-logging work as well
- provide commons-discovery
* Thu Mar 13 2008 mvyskocil@suse.cz
- merged with jpackage 1.7
- update to 0.4
* Mon Sep 25 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 0.3 from JPackage.org
* Mon Sep  6 2004 skh@suse.de
- Initial package created with version 0.2 (JPackage 1.5)
